@@ -19,24 +19,30 @@ from pytorch_lightning.callbacks.gradient_accumulation_scheduler import Gradient
 from pytorch_lightning.callbacks.lambda_function import LambdaCallback
 from pytorch_lightning.callbacks.lr_monitor import LearningRateMonitor
 from pytorch_lightning.callbacks.model_checkpoint import ModelCheckpoint
+from pytorch_lightning.callbacks.prediction_writer import BasePredictionWriter
 from pytorch_lightning.callbacks.progress import ProgressBar, ProgressBarBase
 from pytorch_lightning.callbacks.pruning import ModelPruning
 from pytorch_lightning.callbacks.quantization import QuantizationAwareTraining
-from pytorch_lightning.callbacks.swa import StochasticWeightAveraging
+from pytorch_lightning.callbacks.stochastic_weight_avg import StochasticWeightAveraging
+from pytorch_lightning.callbacks.timer import Timer
+from pytorch_lightning.callbacks.xla_stats_monitor import XLAStatsMonitor
 
 __all__ = [
-    'BackboneFinetuning',
-    'BaseFinetuning',
-    'Callback',
-    'EarlyStopping',
-    'GPUStatsMonitor',
-    'GradientAccumulationScheduler',
-    'LambdaCallback',
-    'LearningRateMonitor',
-    'ModelCheckpoint',
-    'ModelPruning',
-    'ProgressBar',
-    'ProgressBarBase',
-    'QuantizationAwareTraining',
-    'StochasticWeightAveraging',
+    "BackboneFinetuning",
+    "BaseFinetuning",
+    "Callback",
+    "EarlyStopping",
+    "GPUStatsMonitor",
+    "XLAStatsMonitor",
+    "GradientAccumulationScheduler",
+    "LambdaCallback",
+    "LearningRateMonitor",
+    "ModelCheckpoint",
+    "ModelPruning",
+    "BasePredictionWriter",
+    "ProgressBar",
+    "ProgressBarBase",
+    "QuantizationAwareTraining",
+    "StochasticWeightAveraging",
+    "Timer",
 ]
