@@ -25,14 +25,14 @@ from torch.optim.lr_scheduler import _LRScheduler
 import pytorch_lightning as pl
 from pytorch_lightning.callbacks import Callback
 from pytorch_lightning.loggers.base import DummyLogger
-from pytorch_lightning.utilities import DeviceType, rank_zero_warn
+from pytorch_lightning.utilities import rank_zero_warn
 from pytorch_lightning.utilities.cloud_io import get_filesystem
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from pytorch_lightning.utilities.parsing import lightning_hasattr, lightning_setattr
 
 # check if ipywidgets is installed before importing tqdm.auto
 # to ensure it won't fail and a progress bar is displayed
-if importlib.util.find_spec('ipywidgets') is not None:
+if importlib.util.find_spec("ipywidgets") is not None:
     from tqdm.auto import tqdm
 else:
     from tqdm import tqdm
@@ -40,28 +40,28 @@ else:
 log = logging.getLogger(__name__)
 
 
-def _determine_lr_attr_name(trainer: 'pl.Trainer', model: 'pl.LightningModule') -> str:
+def _determine_lr_attr_name(trainer: "pl.Trainer", model: "pl.LightningModule") -> str:
     if isinstance(trainer.auto_lr_find, str):
         if not lightning_hasattr(model, trainer.auto_lr_find):
             raise MisconfigurationException(
-                f'`auto_lr_find` was set to {trainer.auto_lr_find}, however'
-                ' could not find this as a field in `model` or `model.hparams`.'
+                f"`auto_lr_find` was set to {trainer.auto_lr_find}, however"
+                " could not find this as a field in `model` or `model.hparams`."
             )
         return trainer.auto_lr_find
 
-    attr_options = ('lr', 'learning_rate')
+    attr_options = ("lr", "learning_rate")
     for attr in attr_options:
         if lightning_hasattr(model, attr):
             return attr
 
     raise MisconfigurationException(
-        'When `auto_lr_find=True`, either `model` or `model.hparams` should'
-        f' have one of these fields: {attr_options} overridden.'
+        "When `auto_lr_find=True`, either `model` or `model.hparams` should"
+        f" have one of these fields: {attr_options} overridden."
     )
 
 
-class _LRFinder(object):
-    """ LR finder object. This object stores the results of lr_find().
+class _LRFinder:
+    """LR finder object. This object stores the results of lr_find().
 
     Args:
         mode: either `linear` or `exponential`, how to increase lr after each step
@@ -87,8 +87,7 @@ class _LRFinder(object):
     """
 
     def __init__(self, mode: str, lr_min: float, lr_max: float, num_training: int):
-        assert mode in ('linear', 'exponential'), \
-            'mode should be either `linear` or `exponential`'
+        assert mode in ("linear", "exponential"), "mode should be either `linear` or `exponential`"
 
         self.mode = mode
         self.lr_min = lr_min
@@ -99,9 +98,9 @@ class _LRFinder(object):
         self._total_batch_idx = 0  # for debug purpose
 
     def _exchange_scheduler(self, configure_optimizers: Callable):
-        """ Decorate configure_optimizers methods such that it returns the users
-            originally specified optimizer together with a new scheduler that
-            that takes care of the learning rate search.
+        """Decorate configure_optimizers methods such that it returns the users
+        originally specified optimizer together with a new scheduler that
+        that takes care of the learning rate search.
         """
 
         @wraps(configure_optimizers)
@@ -111,8 +110,7 @@ class _LRFinder(object):
             optim_conf = configure_optimizers()
             if isinstance(optim_conf, Optimizer):
                 optimizers = [optim_conf]
-            elif isinstance(optim_conf, (list, tuple)) and len(optim_conf) == 2 \
-                    and isinstance(optim_conf[0], list):
+            elif isinstance(optim_conf, (list, tuple)) and len(optim_conf) == 2 and isinstance(optim_conf[0], list):
                 optimizers, _ = optim_conf
             elif isinstance(optim_conf, dict):
                 optimizers = [optim_conf["optimizer"]]
@@ -123,8 +121,8 @@ class _LRFinder(object):
 
             if len(optimizers) != 1:
                 raise MisconfigurationException(
-                    f'`model.configure_optimizers()` returned {len(optimizers)}, but'
-                    ' learning rate finder only works with single optimizer'
+                    f"`model.configure_optimizers()` returned {len(optimizers)}, but"
+                    " learning rate finder only works with single optimizer"
                 )
 
             optimizer = optimizers[0]
@@ -135,14 +133,14 @@ class _LRFinder(object):
                 param_group["initial_lr"] = new_lr
 
             args = (optimizer, self.lr_max, self.num_training)
-            scheduler = _LinearLR(*args) if self.mode == 'linear' else _ExponentialLR(*args)
+            scheduler = _LinearLR(*args) if self.mode == "linear" else _ExponentialLR(*args)
 
-            return [optimizer], [{'scheduler': scheduler, 'interval': 'step'}]
+            return [optimizer], [{"scheduler": scheduler, "interval": "step"}]
 
         return func
 
     def plot(self, suggest: bool = False, show: bool = False):
-        """ Plot results from lr_find run
+        """Plot results from lr_find run
         Args:
             suggest: if True, will mark suggested lr to use with a red point
 
@@ -157,7 +155,7 @@ class _LRFinder(object):
 
         # Plot loss as a function of the learning rate
         ax.plot(lrs, losses)
-        if self.mode == 'exponential':
+        if self.mode == "exponential":
             ax.set_xscale("log")
         ax.set_xlabel("Learning rate")
         ax.set_ylabel("Loss")
@@ -165,7 +163,7 @@ class _LRFinder(object):
         if suggest:
             _ = self.suggestion()
             if self._optimal_idx:
-                ax.plot(lrs[self._optimal_idx], losses[self._optimal_idx], markersize=10, marker='o', color='red')
+                ax.plot(lrs[self._optimal_idx], losses[self._optimal_idx], markersize=10, marker="o", color="red")
 
         if show:
             plt.show()
@@ -173,7 +171,7 @@ class _LRFinder(object):
         return fig
 
     def suggestion(self, skip_begin: int = 10, skip_end: int = 1):
-        """ This will propose a suggestion for choice of initial learning rate
+        """This will propose a suggestion for choice of initial learning rate
         as the point with the steepest negative gradient.
 
         Returns:
@@ -190,30 +188,30 @@ class _LRFinder(object):
             return self.results["lr"][self._optimal_idx]
         # todo: specify the possible exception
         except Exception:
-            log.exception('Failed to compute suggesting for `lr`. There might not be enough points.')
+            log.exception("Failed to compute suggesting for `lr`. There might not be enough points.")
             self._optimal_idx = None
 
 
 def lr_find(
-    trainer: 'pl.Trainer',
-    model: 'pl.LightningModule',
+    trainer: "pl.Trainer",
+    model: "pl.LightningModule",
     min_lr: float = 1e-8,
     max_lr: float = 1,
     num_training: int = 100,
-    mode: str = 'exponential',
+    mode: str = "exponential",
     early_stop_threshold: float = 4.0,
     update_attr: bool = False,
 ) -> Optional[_LRFinder]:
     """See :meth:`~pytorch_lightning.tuner.tuning.Tuner.lr_find`"""
     if trainer.fast_dev_run:
-        rank_zero_warn('Skipping learning rate finder since fast_dev_run is enabled.', UserWarning)
+        rank_zero_warn("Skipping learning rate finder since fast_dev_run is enabled.", UserWarning)
         return
 
     # Determine lr attr
     if update_attr:
         lr_attr_name = _determine_lr_attr_name(trainer, model)
 
-    save_path = os.path.join(trainer.default_root_dir, 'lr_find_temp_model.ckpt')
+    save_path = os.path.join(trainer.default_root_dir, "lr_find_temp_model.ckpt")
 
     __lr_finder_dump_params(trainer, model)
 
@@ -230,14 +228,14 @@ def lr_find(
     trainer.logger = DummyLogger()
 
     # Max step set to number of iterations
-    trainer.max_steps = num_training
+    trainer.fit_loop.max_steps = num_training
 
     # Disable standard progress bar for fit
     if trainer.progress_bar_callback:
         trainer.progress_bar_callback.disable()
 
     # Required for saving the model
-    trainer.optimizers, trainer.schedulers = [], [],
+    trainer.optimizers, trainer.lr_schedulers = [], []
     trainer.model = model
 
     # Dump model checkpoint
@@ -251,15 +249,15 @@ def lr_find(
 
     # Prompt if we stopped early
     if trainer.global_step != num_training:
-        log.info(f'LR finder stopped early after {trainer.global_step} steps due to diverging loss.')
+        log.info(f"LR finder stopped early after {trainer.global_step} steps due to diverging loss.")
 
     # Transfer results from callback to lr finder object
-    lr_finder.results.update({'lr': trainer.callbacks[0].lrs, 'loss': trainer.callbacks[0].losses})
-    lr_finder._total_batch_idx = trainer.total_batch_idx  # for debug purpose
+    lr_finder.results.update({"lr": trainer.callbacks[0].lrs, "loss": trainer.callbacks[0].losses})
+    lr_finder._total_batch_idx = trainer.fit_loop.total_batch_idx  # for debug purpose
 
     # Reset model state
     if trainer.is_global_zero:
-        trainer.checkpoint_connector.restore(str(save_path), on_gpu=trainer._device_type == DeviceType.GPU)
+        trainer.checkpoint_connector.restore(str(save_path))
         fs = get_filesystem(str(save_path))
         if fs.exists(save_path):
             fs.rm(save_path)
@@ -275,7 +273,7 @@ def lr_find(
 
         # TODO: log lr.results to self.logger
         lightning_setattr(model, lr_attr_name, lr)
-        log.info(f'Learning rate set to {lr}')
+        log.info(f"Learning rate set to {lr}")
 
     return lr_finder
 
@@ -283,28 +281,28 @@ def lr_find(
 def __lr_finder_dump_params(trainer, model):
     # Prevent going into infinite loop
     trainer.__dumped_params = {
-        'auto_lr_find': trainer.auto_lr_find,
-        'callbacks': trainer.callbacks,
-        'logger': trainer.logger,
-        'max_steps': trainer.max_steps,
-        'checkpoint_callback': trainer.checkpoint_callback,
-        'current_epoch': trainer.current_epoch,
-        'configure_optimizers': model.configure_optimizers,
+        "auto_lr_find": trainer.auto_lr_find,
+        "callbacks": trainer.callbacks,
+        "logger": trainer.logger,
+        "max_steps": trainer.max_steps,
+        "checkpoint_callback": trainer.checkpoint_callback,
+        "current_epoch": trainer.current_epoch,
+        "configure_optimizers": model.configure_optimizers,
     }
 
 
 def __lr_finder_restore_params(trainer, model):
-    trainer.auto_lr_find = trainer.__dumped_params['auto_lr_find']
-    trainer.logger = trainer.__dumped_params['logger']
-    trainer.callbacks = trainer.__dumped_params['callbacks']
-    trainer.max_steps = trainer.__dumped_params['max_steps']
-    trainer.current_epoch = trainer.__dumped_params['current_epoch']
-    model.configure_optimizers = trainer.__dumped_params['configure_optimizers']
+    trainer.auto_lr_find = trainer.__dumped_params["auto_lr_find"]
+    trainer.logger = trainer.__dumped_params["logger"]
+    trainer.callbacks = trainer.__dumped_params["callbacks"]
+    trainer.fit_loop.max_steps = trainer.__dumped_params["max_steps"]
+    trainer.fit_loop.current_epoch = trainer.__dumped_params["current_epoch"]
+    model.configure_optimizers = trainer.__dumped_params["configure_optimizers"]
     del trainer.__dumped_params
 
 
 class _LRCallback(Callback):
-    """ Special callback used by the learning rate finder. This callbacks log
+    """Special callback used by the learning rate finder. This callbacks log
     the learning rate before each batch and log the corresponding loss after
     each batch.
 
@@ -326,7 +324,7 @@ class _LRCallback(Callback):
         num_training: int,
         early_stop_threshold: float = 4.0,
         progress_bar_refresh_rate: int = 0,
-        beta: float = 0.98
+        beta: float = 0.98,
     ):
         self.num_training = num_training
         self.early_stop_threshold = early_stop_threshold
@@ -339,34 +337,34 @@ class _LRCallback(Callback):
         self.progress_bar = None
 
     def on_batch_start(self, trainer, pl_module):
-        """ Called before each training batch, logs the lr that will be used """
-        if (trainer.batch_idx + 1) % trainer.accumulate_grad_batches != 0:
+        """Called before each training batch, logs the lr that will be used"""
+        if (trainer.fit_loop.batch_idx + 1) % trainer.accumulate_grad_batches != 0:
             return
 
         if self.progress_bar_refresh_rate and self.progress_bar is None:
-            self.progress_bar = tqdm(desc='Finding best initial lr', total=self.num_training)
+            self.progress_bar = tqdm(desc="Finding best initial lr", total=self.num_training)
 
-        self.lrs.append(trainer.lr_schedulers[0]['scheduler'].lr[0])
+        self.lrs.append(trainer.lr_schedulers[0]["scheduler"].lr[0])
 
     def on_train_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
-        """ Called when the training batch ends, logs the calculated loss """
-        if (trainer.batch_idx + 1) % trainer.accumulate_grad_batches != 0:
+        """Called when the training batch ends, logs the calculated loss"""
+        if (trainer.fit_loop.batch_idx + 1) % trainer.accumulate_grad_batches != 0:
             return
 
         if self.progress_bar:
             self.progress_bar.update()
 
-        current_loss = trainer.train_loop.running_loss.last().item()
+        current_loss = trainer.fit_loop.running_loss.last().item()
         current_step = trainer.global_step
 
         # Avg loss (loss with momentum) + smoothing
         self.avg_loss = self.beta * self.avg_loss + (1 - self.beta) * current_loss
-        smoothed_loss = self.avg_loss / (1 - self.beta**(current_step + 1))
+        smoothed_loss = self.avg_loss / (1 - self.beta ** (current_step + 1))
 
         # Check if we diverging
         if self.early_stop_threshold is not None:
             if current_step > 1 and smoothed_loss > self.early_stop_threshold * self.best_loss:
-                trainer.max_steps = current_step  # stop signal
+                trainer.fit_loop.max_steps = current_step  # stop signal
                 if self.progress_bar:
                     self.progress_bar.close()
 
@@ -391,13 +389,14 @@ class _LinearLR(_LRScheduler):
 
         last_epoch: the index of last epoch. Default: -1.
     """
+
     last_epoch: int
     base_lrs: Sequence
 
     def __init__(self, optimizer: torch.optim.Optimizer, end_lr: float, num_iter: int, last_epoch: int = -1):
         self.end_lr = end_lr
         self.num_iter = num_iter
-        super(_LinearLR, self).__init__(optimizer, last_epoch)
+        super().__init__(optimizer, last_epoch)
 
     def get_lr(self):
         curr_iter = self.last_epoch + 1
@@ -429,20 +428,21 @@ class _ExponentialLR(_LRScheduler):
 
         last_epoch: the index of last epoch. Default: -1.
     """
+
     last_epoch: int
     base_lrs: Sequence
 
     def __init__(self, optimizer: torch.optim.Optimizer, end_lr: float, num_iter: int, last_epoch: int = -1):
         self.end_lr = end_lr
         self.num_iter = num_iter
-        super(_ExponentialLR, self).__init__(optimizer, last_epoch)
+        super().__init__(optimizer, last_epoch)
 
     def get_lr(self):
         curr_iter = self.last_epoch + 1
         r = curr_iter / self.num_iter
 
         if self.last_epoch > 0:
-            val = [base_lr * (self.end_lr / base_lr)**r for base_lr in self.base_lrs]
+            val = [base_lr * (self.end_lr / base_lr) ** r for base_lr in self.base_lrs]
         else:
             val = [base_lr for base_lr in self.base_lrs]
         self._lr = val
